@@ -15,7 +15,7 @@
 # limitations under the License.
 # ---------------------------
 from __future__ import annotations
-from typing import Any
+from typing import Any, Union
 from selenium.webdriver.remote.webelement import WebElement
 
 from QWeb.internal import browser
@@ -45,7 +45,7 @@ def execute_javascript(script: str, *args) -> Any:
     return driver.execute_script(script, *args)
 
 
-def get_visibility(web_elements: list[WebElement]) -> list[WebElement]:
+def get_visibility(web_elements: list[WebElement]) -> list[dict]:
     """Return web element objects.
 
     Object contains element itself, offset-status,
@@ -330,7 +330,8 @@ def get_by_label(locator_text: str, css: str, level: int,
     return execute_javascript(js, locator_text.replace("\'", "\\'"), css, level, partial_match)
 
 
-def get_parent_list(locator_element: str, css: str) -> list[WebElement]:
+def get_parent_list(locator_element: Union[WebElement, str], css: str
+                    ) -> Union[WebElement, list[WebElement]]:
     """Get parent list for web element.
 
     Parameters
@@ -499,6 +500,23 @@ def get_all_input_elements_from_shadow_dom() -> list[WebElement]:
     return execute_javascript(js)
 
 
+def get_all_dropdown_elements_from_shadow_dom() -> list[WebElement]:
+    js = get_recursive_walk() + """
+    function find_all_select_elements_from_shadow_dom(){
+        var results = [];
+        var elem = recursiveWalk(document.body, function(node) {
+            if (node.tagName == "SELECT") {
+                    results.push(node);
+            }
+
+        });
+        return results;
+    }
+
+    return(find_all_select_elements_from_shadow_dom(arguments[0]))"""
+    return execute_javascript(js)
+
+
 def get_item_elements_from_shadow_dom(tag: str) -> list[WebElement]:
     js = get_recursive_walk() + """
     function find_item_elements_from_shadow_dom(tag){
